@@ -53,7 +53,7 @@ class Vm(object):
             self.debug = True
             log.basicConfig(level='DEBUG')
 
-        log.info("Enter with host_type={} hypervisor_type={} ip={}, port={}, user={}, password={}, private_key_file={}, debug={}".
+        log.debug("Enter with host_type={} hypervisor_type={} ip={}, port={}, user={}, password={}, private_key_file={}, debug={}".
                  format(host_type, hypervisor_type, ip, port, user, password, private_key_file, debug))
 
         # public class attributs
@@ -71,11 +71,12 @@ class Vm(object):
         self._statistics = {}  # Internal representation of statistics
         self._vms = []         # Internal representation of each VMs
         self._vms_total = {}   # Total VMs statistics
-        self._vms_disks = []   # Internal representation of each VM sdisks info
+        self._vms_disks = []   # Internal representation of each VM disks info
         self._vms_disks_dict = {} # temp object
         self._vms_esx_id_map = {} # wid to vm_name mapping
         self._vms_esx_cpu = {}    # dict of vm_id containing nb_cpu
         self._vms_esx_memory = {} # dict of vm_id containing memory size
+        self._vms_esx_disks = {}  # dict of vm_id containing disk size in
 
     def connect(self):
         self.ssh.connect()
@@ -99,7 +100,7 @@ class Vm(object):
         Commands to run depends on host_type
         Return: json
         """
-        log.info('Enter')
+        log.debug('Enter')
         self._get_nbcpu()
         self._get_loadavg()
         if self.host_type == 'Linux':
@@ -115,13 +116,14 @@ class Vm(object):
         Get server VMS related statistics
         Return: json
         """
-        log.info('Enter')
+        log.debug('Enter')
         if self.hypervisor_type == 'kvm':
             self._get_processes_kvm()
             self._get_vms_disk_kvm()
         elif self.hypervisor_type == 'esx':
             self._build_vms_esx_cpu()
             self._build_vms_esx_memory()
+            self._build_vms_esx_disk()
             self._get_processes_esx()
         result = {}
         result['vms'] = self._vms
@@ -134,7 +136,7 @@ class Vm(object):
         Fills self._statistics with the number of CPU on the server
         Same command used for for Linux and ESX system
         """
-        log.info("Enter")
+        log.debug("Enter")
 
         self.ssh.shell_send(["cat /proc/cpuinfo | grep processor | wc -l\n"])
         log.debug("output={}".format(self.ssh.output))
@@ -142,7 +144,7 @@ class Vm(object):
         # This is the first line with a single number in the line
         nb_cpu_match = re.search("(\d+)\n", str(self.ssh.output))
         if nb_cpu_match:
-            nb_cpu = nb_cpu_match.groups(0)[0]
+            nb_cpu = int(nb_cpu_match.groups(0)[0])
             log.debug("nb_cpu={}".format(nb_cpu))
             self._statistics['nb_cpu'] = nb_cpu
 
@@ -158,7 +160,7 @@ class Vm(object):
             }
         Different commands for Linux system (cat /proc/loadavg) and ESX (uptime)
         """
-        log.info("Enter")
+        log.debug("Enter")
         load_1mn = ""
         load_5mn = ""
         load_15mn = ""
@@ -198,7 +200,7 @@ class Vm(object):
                 'available': ...
             }
         """
-        log.info("Enter")
+        log.debug("Enter")
         # Memory load typical output (skip unecessary lines):
         # MemTotal:       264097732 kB
         # MemFree:         5160488 kB
@@ -210,15 +212,15 @@ class Vm(object):
         memory_available = 0
         mem_total_match = re.search("MemTotal:\s+(\d+) kB", str(self.ssh.output))
         if mem_total_match:
-            memory_total = mem_total_match.groups(0)[0]
+            memory_total = int(mem_total_match.groups(0)[0])
             self._statistics['memory']['total'] = memory_total
         mem_free_match = re.search("MemFree:\s+(\d+) kB", str(self.ssh.output))
         if mem_free_match:
-            memory_free = mem_free_match.groups(0)[0]
+            memory_free = int(mem_free_match.groups(0)[0])
             self._statistics['memory']['free'] = memory_free
         mem_available_match = re.search("MemAvailable:\s+(\d+) kB", str(self.ssh.output))
         if mem_available_match:
-            memory_available = mem_available_match.groups(0)[0]
+            memory_available = int(mem_available_match.groups(0)[0])
             self._statistics['memory']['available'] = memory_available
         log.debug("memory_total={}, memory_free={}, memory_available={}".
                   format(memory_total, memory_free, memory_available))
@@ -235,7 +237,7 @@ class Vm(object):
                 'available': ...
             }
         """
-        log.info("Enter")
+        log.debug("Enter")
         # command has several values : total, minFree, free and some others.
         # use 'total', 'free' and compute available as total - free
         # this is how % is shown in vcenter for free so it matches
@@ -287,7 +289,7 @@ class Vm(object):
                 }
             }
         """
-        log.info("Enter")
+        log.debug("Enter")
         # Typical output (skip unessary lines):
         # Filesystem                   1G-blocks  Used Available Use% Mounted on
         # udev                              126G    0G      126G   0% /dev
@@ -315,6 +317,8 @@ class Vm(object):
                 self._statistics['disk'][mounted]['used'] = used
                 self._statistics['disk'][mounted]['available'] = available
                 self._statistics['disk'][mounted]['used_percent'] = used_percent
+                self._statistics['disk'][mounted]['type'] = 'KVM'
+
 
     def _get_disk_esx(self):
         """
@@ -333,7 +337,7 @@ class Vm(object):
                 }
             }
         """
-        log.info("Enter")
+        log.debug("Enter")
         # Typical output (skip unessary lines)
         # not esx does not support -BG options
         # [root@uranium:~] df -m
@@ -365,6 +369,8 @@ class Vm(object):
                 self._statistics['disk'][mounted]['used'] = used
                 self._statistics['disk'][mounted]['available'] = available
                 self._statistics['disk'][mounted]['used_percent'] = used_percent
+                self._statistics['disk'][mounted]['type'] = 'ESXI'
+
 
     def _get_processes_esx(self):
         """
@@ -381,13 +387,14 @@ class Vm(object):
         Note: the vmid used in other commands is the "World ID" (need to be extracted)
         We use Display name as VM id
         """
-        log.info("Enter")
+        log.debug("Enter")
         self.ssh.shell_send(["esxcli vm process list\n"])
         self._vms = []
         self._vms_total = {}
         self._vms_total['cpu'] = 0
         self._vms_total['memory'] = 0
         self._vms_total['number'] = 0
+        self._vms_total['disk'] = 0
         self._vms_esx_id_map = {}
         esx_start = False
         esx_end = False
@@ -414,7 +421,7 @@ class Vm(object):
                     log.debug("Found {} vm_esxid={}".format(vm_name, vm_esxid))
                     self._vms_esx_id_map[vm_esxid] = vm_name
                     if vm_esxid in self._vms_esx_memory:
-                        vm_memory = self._vms_esx_memory[vm_esxid]
+                        vm_memory = int(int(self._vms_esx_memory[vm_esxid]) / 1024)
                         self._vms_total['memory'] += int(vm_memory)
                     else:
                         log.error("Could not find vm memory for vm_esxi={}".format(vm_esxid))
@@ -442,6 +449,14 @@ class Vm(object):
                     else:
                         log.error("Could not find nb of cpu for vm_name={}".format(vm_name))
                         ret = False
+                    if vm_name in self._vms_esx_disks:
+                        vm['disk'] = self._vms_esx_disks[vm_name]
+                        vm['type'] = 'ESXI'
+                        self._vms_total['disk'] += vm['disk']
+                        log.debug("vms_total_disk={}".format(self._vms_total['disk']))
+                    else:
+                        log.error("Could not find disk size for vm_name={}".format(vm_name))
+                        ret = False
                     self._vms.append(vm)
                 else:
                     log.warning("got unexpected instance format instance={}".format(instance))
@@ -453,7 +468,7 @@ class Vm(object):
         VM instance is like 001, 011, 122 and so on.
         It should be extracted from server name (ex: uranium-tam-esx42)
         """
-        log.info("Enter with name={}".format(name))
+        log.debug("Enter with name={}".format(name))
         match_inst = re.search("(?P<inst>\d+)$", name)
         if match_inst:
             inst = match_inst.group('inst')
@@ -476,7 +491,7 @@ class Vm(object):
         5087642  5087630  vmx-vcpu-2:neutron-esx01 [apasta] FMG_VM64_ESXI
         5087643  5087630  vmx-vcpu-3:neutron-esx01 [apasta] FMG_VM64_ESXI         <- 4 cpus
         """
-        log.info("Enter")
+        log.debug("Enter")
         self._vms_esx_cpu = {}
         self.ssh.shell_send(["ps -u\n"])
         for line in self.ssh.output.splitlines():
@@ -498,7 +513,7 @@ class Vm(object):
        vm.48361 n     125647             4      48361      2097152    2097152          0         -1         -1         -3      48072      40392    2084412    2053692          0          0          0          0    2066432      20968          0          0      14076      10204       12740              n         1
         using field 5 (worldGrp) and 6 (memSizeLimit)
         """
-        log.info("Enter")
+        log.debug("Enter")
         self._vms_esx_memory = {}
         self.ssh.shell_send(["memstats -r vm-stats\n"])
         for line in self.ssh.output.splitlines():
@@ -522,7 +537,7 @@ class Vm(object):
         one (timestamp=). If the ending one is not there, lines need to be
         concatenated in one before it is tokenized
         """
-        log.info("Enter")
+        log.debug("Enter")
         self.ssh.shell_send(["ps -xww | grep qemu-system\n"])
         self._vms_total = {}
         self._vms_total['cpu'] = 0
@@ -553,7 +568,7 @@ class Vm(object):
                     kvm_end = False
                     need_tokenize = True
                 else :
-                    log.info("Start without end, line is split, first fragment seen")
+                    log.debug("Start without end, line is split, first fragment seen")
                     full_line = line
             else:
                 if kvm_end:
@@ -595,8 +610,7 @@ class Vm(object):
             'template': ...
         }
         """
-        log.info("Enter with line={}".format(line))
-
+        log.debug("Enter with line={}".format(line))
         vm_id = None
         cpu = None
         memory = None
@@ -612,13 +626,13 @@ class Vm(object):
         # Number of CPU assigned to the VM
         cpu_match = re.search("\s-smp\s(\d+)(?:,|\s)", line)
         if cpu_match:
-            cpu = cpu_match.groups(0)[0]
+            cpu = int(cpu_match.groups(0)[0])
             log.debug("cpu={}".format(cpu))
 
         # Allocated memory in Mb
         memory_match = re.search("\s-m\s(\d+)(?:,|\s)", line)
         if memory_match:
-            memory = memory_match.groups(0)[0]
+            memory = int(memory_match.groups(0)[0])
             log.debug("memory={}".format(memory))
 
         # Running template
@@ -670,21 +684,67 @@ class Vm(object):
         ../..
         Need to addition for each VM the size of each disks in bytes
         """
-        log.info('Enter with vmpath={}'.format(vmpath))
-        cmd="for i in `virsh list --all | awk '{print $2}'`; do file "+vmpath+"/$i/* ; done"
+        log.debug('Enter with vmpath={}'.format(vmpath))
+        cmd = "for i in `virsh list --all | awk '{print $2}'`; do file "+vmpath+"/$i/* ; done"
         self.ssh.shell_send([cmd+"\n"])
         for line in self.ssh.output.splitlines():
             log.debug("line={}".format(line))
             self._extract_vms_disk(vmpath, line)
         for id in self._vms_disks_dict:
             size = self._vms_disks_dict[id]
-            self._vms_disks.append({'id': id, 'size': size})
+            self._vms_disks.append({'id': id, 'size': size, 'type': 'KVM'})
+
+    def _build_vms_esx_disk(self):
+        """
+        Parse datastore, retrieve disk usage for each VM.
+        build self._vms_esx_disks using vm name as a key
+        du -h /vmfs/volumes/datastore-Uranium/machines
+        sample:
+        [root@uranium:~] du -h /vmfs/volumes/datastore-Uranium/machines
+        4.9G    /vmfs/volumes/datastore-Uranium/machines/uranium-esx81 [melkhatib] FGT_VM64_ESXI
+        90.1G   /vmfs/volumes/datastore-Uranium/machines/uranium-esx51 [lpizziniaco] FPOC-17_VM64_ESXI
+        20.5G   /vmfs/volumes/datastore-Uranium/machines/uranium-FSA-esx42 [panchals] FSA_VM64_ESXI
+        12.6G   /vmfs/volumes/datastore-Uranium/machines/uranium-esx37 [emete] Debian9_ESXI
+        Result to be provided in MB
+        """
+        log.debug("Enter")
+        cmd = "(p=`ls -1 /vmfs/volumes/* | grep datastore | sed s/:$//`; du -h $p/machines) | awk '// { print $1 \", \" $2}'"
+        self.ssh.shell_send([cmd+"\n"])
+        for line in self.ssh.output.splitlines():
+            log.debug("line={}".format(line))
+            match_vm = re.search("(?P<size>\d+\.?\d+?)(?P<unit>G|M|K|T),\s(?P<machine>\S+)", line)
+            if match_vm:
+                size = match_vm.group('size')
+                unit = match_vm.group('unit')
+                machine = match_vm.group('machine')
+                log.debug("Found size={} unit={} machine={}".format(size, unit, machine))
+                # get machine id from full name ex: /vmfs/volumes/datastore-Neutron/machines/neutron-esx36
+                match_name = re.search("machines\/(?P<name>\S+)$", machine)
+                if match_name:
+                    name = match_name.group('name')
+                    log.debug("Found name={}".format(name))
+                    if unit == 'G':
+                        value = int(float(size) * 1024)
+                    elif unit == 'M':
+                        value = int(float(size))
+                    elif unit == 'T':
+                        value == int(float(size) * 1024 * 1024)
+                    elif unit == 'K':
+                        value == int(float(size) / 1024)
+                    else:
+                        log.error("Unexpected disk size unit={} on esx machine={}".format(unit, name))
+                        value = 0
+                    self._vms_esx_disks[name] = value
+                    log.debug("name={} disk size={}".format(name, value))
+                else:
+                    log.debug("Could not extract machine name from machine={}".format(machine))
+
 
     def _extract_vms_disk(self, vmpath, line):
         """
-        Parse output to get all vms disk consumtion
+        Parse output to get all vms disk consumption
         """
-        log.info("Enter with vmpath={} line={}".format(vmpath, line))
+        log.debug("Enter with vmpath={} line={}".format(vmpath, line))
         d_match = re.search(vmpath+"/(?P<id>[a-zA-Z0-9_\-\.\/s]+)/",line)
         if d_match:
             id = d_match.group("id")
@@ -696,30 +756,28 @@ class Vm(object):
                     self._vms_disks_dict[id] = int(size)
                 else:
                     self._vms_disks_dict[id] = int(self._vms_disks_dict[id]) + int(size)
-                log.debug("id={} size={} total={} ".format(id, size, self._vms_disks_dict[id] ))
-
-
+                log.debug("id={} file size={} disk total={} ".format(id, size, self._vms_disks_dict[id] ))
 
     def dump_statistics(self):
         """
         For debugging purpose, returns a formated json of
         self._statistics
         """
-        log.info('Enter')
+        log.debug('Enter')
         print(json.dumps(self._statistics, indent=4, sort_keys=True))
 
     def dump_vms(self):
        """
        For debugging purpose, returns a formated json of self._vms
        """
-       log.info('Enter')
+       log.debug('Enter')
        print(json.dumps(self._vms, indent=4, sort_keys=True))
 
     def dump_vms_total(self):
         """
         For debugging purpose, returns a formated json of self._vms_total
         """
-        log.info('Enter')
+        log.debug('Enter')
         print(json.dumps(self._vms_total, indent=4, sort_keys=True))
 
 
